from tkinter import *
from tkinter import filedialog
import shutil


def explorer(title=None, types=None, dir=None, where_to_copy=None):
    root = Tk()
    root.call('wm', 'attributes', '.', '-topmost', '1')
    root.withdraw()
    scr = filedialog.askopenfilename(
        initialdir=str(dir) if dir else '',
        title=str(title) if title else 'Select file', initialfile=str(types) if types else None)
    root.destroy()
    if where_to_copy and scr != '':

        path = str(shutil.copy(scr, str(where_to_copy)))
        return path
    else:
        return scr


from setuptools import setup

setup(
    name='easyGuiCover',
    packages=['easyGuiCover'],
    version='0.0.1',
    author='Luka',
    author_email='app6onpython@gmail.com',
    description='This is easy library to open explorer on top of other screens!',
    keywords=['easyGuiCover', 'Cover', 'easyguicover', 'easygui', 'gui', 'easy', 'Easygui', 'Gui', 'Easy', 'cover'],
    install_requires=[],
    classifiers=[
        'Programming Language :: Python :: 3.9'
    ]
)
